% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scale_smile.R
\name{scale_smile_continuous}
\alias{scale_smile_continuous}
\alias{scale_smile}
\title{Scales for smiling and frowning}
\usage{
scale_smile_continuous(..., range = c(-1, 1), midpoint = mean)

scale_smile(..., range = c(-1, 1), midpoint = mean)
}
\arguments{
\item{...}{Other arguments passed onto \code{\link[ggplot2]{continuous_scale}} to control name, limits, breaks, labels and so forth.}

\item{range}{Output range of smiles. +1 corresponds to a full smile and -1 corresponds to a full frown.}

\item{midpoint}{A value or function of your data that will return a neutral/straight face, i.e. \code{:-|}}
}
\description{
\code{scale_smile} lets you customise how smiles are generated from your data.
It also lets you tweak the appearance of legends and so on.
}
\details{
Use \code{range} to vary how happily/sadly your maximum/minimum values are represented.
Minima smaller than -1 and maxima greater than +1 are possible but might look odd!
You can use \code{midpoint} to set a specific 'zero' value in your data or to have smiles represented as relative to average.

The function \code{scale_smile} is an alias of \code{scale_smile_continuous}.
At some point we might also want to design a \code{scale_smile_discrete}, \code{scale_smile_manual} and so on.

Legends are a work in progress. In particular, \code{size} mappings might produce odd results.
}
\examples{
library(ggplot2)
p <- ggplot(iris) +
    aes(Sepal.Width, Sepal.Length, fill = Species, smile = Sepal.Length) +
    geom_chernoff()
p
p + scale_smile_continuous(midpoint = min)
p + scale_smile_continuous(range = c(-.5, 2))

}
\seealso{
\code{\link{geom_chernoff}}, \code{\link{scale_brow}}
}
